Methodology
===========


There are several documents on the methodology of GEOUNED

`Publication <https://www.mdpi.com/2673-4362/4/2/31>`_

`User_Guide_GEOUNED_v2.0.pdf <https://github.com/GEOUNED-org/GEOUNED/blob/76ef697c7dca6a828c7498996ff3313859c872f2/docs/User_Guide_GEOUNED_v2.0.pdf>`_

`Training_on_GEOUNED_tool <https://github.com/GEOUNED-org/GEOUNED/blob/76ef697c7dca6a828c7498996ff3313859c872f2/docs/Training_on_GEOUNED_tool.pdf>`_

TODO convert various data sources to rst format for these docs
